@@ -99,9 +99,12 @@ class HardwareDisplayWidget(tk.Frame):
 
             if errmsg is None and val <= self.upper_limit and val >= self.lower_limit:
                 self.ok = True
-            elif np.isnan(val) and errmsg is None:
+            elif not isinstance(val, str) and np.isnan(val) and errmsg is None:
                 # no error and nan returned means checking disabled
                 self.ok = True
+            elif isinstance(val, str) and val == '??':
+                # checking disabled
+                self.ok = True
             else:
                 self.ok = False
 
@@ -172,7 +175,8 @@ class MeerstetterWidget(HardwareDisplayWidget):
             else:
                 raise ValueError('unknown kind: {}'.format(self.kind))
         else:
-            return np.nan, None
+            value = '??' if self.kind == 'status' else np.nan
+            return value, None
 
 
 class ChillerWidget(HardwareDisplayWidget):
